@@ -5,8 +5,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef KORG_VIEWS_KOWHATSNEXTVIEW_H
-#define KORG_VIEWS_KOWHATSNEXTVIEW_H
+#pragma once
 
 #include "baseview.h"
 #include <EventViews/WhatsNextView>
@@ -51,4 +50,3 @@ private:
     EventViews::WhatsNextView *const mView;
 };
 
-#endif
